@@ -14,6 +14,7 @@ from .manual.main import main as manual_main
 from .datapack.main import main as datapack_main
 from .finalyze import main as finalyze_main
 
+# Functions
 def basic_key_check(config: dict, key: str, value_type: type, hint: str, valid: bool) -> bool:
 	bool_return = valid
 	if not config.get(key):
@@ -71,6 +72,8 @@ def build_process(config: dict, setup_database: callable, setup_external_databas
 		setup_external_database (callable|None): Function that will setup the external database (if you need an item in a craft), same format as first
 		user_code (callable|None): Function that will be called after the datapack has been generated, can be used to add custom code to generated some parts of the datapack
 	"""
+	os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
+
 	# Check config format
 	valid = check_config_format(config)
 	if not valid:
@@ -103,7 +106,7 @@ def build_process(config: dict, setup_database: callable, setup_external_databas
 	datapack_main(config)
 
 	# Finalyze build process
-	finalyze_main(config)
+	finalyze_main(config, user_code)
 
 	# Total time
 	total_time = time.time() - START_TIME
